@@ -17,10 +17,12 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 #include <libaio.h>
+#include <errno.h>
+#include <stdlib.h>
 #include <time.h>
 #include "syscall.h"
 
-int io_getevents(io_context_t ctx, long nr, struct io_event *events, struct timespec *timeout)
+int io_getevents(io_context_t ctx, long min_nr, long nr, struct io_event *events, struct timespec *timeout)
 {
-	return sys_io_getevents(ctx, 1, nr, events, timeout);
+	return syscall5(__NR_io_getevents, ctx, min_nr, nr, events, timeout);
 }
