@@ -17,19 +17,21 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 #include <libaio.h>
+#include <errno.h>
+#include <stdlib.h>
 #include <time.h>
-#include "syscall.h"
+#include "vsys_def.h"
 
 int io_queue_run(io_context_t ctx)
 {
-	struct timespec timeout = { 0, 0 };
+	static struct timespec timeout = { 0, 0 };
 	struct io_event event;
 	int ret;
 
-	/* FIXME: batch requests */
-	while (1 == (ret = sys_io_getevents(ctx, 1, 1, &event, &timeout))) {
-		io_callback_t cb = (io_callback_t) (unsigned long) event.data;
-		struct iocb *iocb = (struct iocb *) (unsigned long) event.obj;
+	/* FIXME: batch requests? */
+	while (1 == (ret = vsys_io_getevents(ctx, 1, &event, &timeout))) {
+		io_callback_t cb = (io_callback_t)event.data;
+		struct iocb *iocb = (struct iocb *)event.obj;
 
 		cb(ctx, iocb, event.res, event.res2);
 	}
