@@ -16,12 +16,11 @@
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
+#include <errno.h>
 #include <libaio.h>
 #include "syscall.h"
 
 int io_submit(io_context_t ctx, long nr, struct iocb **iocbs)
 {
-	if (nr >= 0)
-		return sys_io_submit(ctx, nr, iocbs);
-	return -EINVAL;
+	return syscall3(__NR_io_submit, ctx, nr, iocbs);
 }
